VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
END
Attribute VB_Name = "cAdsi"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = True
Option Explicit

Const SUCCESS = 0
Const FAILURE = -1
Const SERVICE_RUNNING = 4
Const SERVICE_STOPPED = 1
Const STATUS_PAUSE = 4

Dim sErrInfo            As String
Dim iRet                As Integer
Dim sNameSpace          As String
Dim sDomain             As String
Dim sComputer           As String
Dim oUtility            As New cUtility

Public Property Get ErrInfo() As String
    ErrInfo = sErrInfo
End Property

Private Property Let ErrInfo(ByVal sNewValue As String)
    sErrInfo = sNewValue
End Property

Public Property Get NameSpace() As String
    NameSpace = sNameSpace
End Property

Public Property Let NameSpace(ByVal sNewValue As String)
    sNameSpace = sNewValue
End Property

Public Property Get Domain() As String
    Domain = sDomain
End Property

Public Property Let Domain(ByVal sNewValue As String)
    sDomain = sNewValue
End Property

Public Property Get Computer() As String
    Computer = sComputer
End Property

Public Property Let Computer(ByVal sNewValue As String)
    sComputer = sNewValue
End Property

Public Function CreateUser(sUserName As String) As Integer
    On Error GoTo ErrorHandler
    sErrInfo = vbNullString

    If (sNameSpace = vbNullString) Then
        sErrInfo = "NameSpace not set"
        CreateUser = FAILURE
        Exit Function
    End If
    
    Dim oContainer As IADsContainer
    Dim oUser As IADsUser
    
    If (sDomain = vbNullString) Then
        Set oContainer = GetObject(sNameSpace & "://" & sComputer)
    Else
        Set oContainer = GetObject(sNameSpace & "://" & sDomain)
    End If
    
    For Each oUser In oContainer
        If oUser.Name = (sUserName) Then
            CreateUser = FAILURE
            Exit Function
        End If
    Next
    
    Set oUser = oContainer.Create("User", sUserName)
    oUser.SetInfo  '// commit
    oUser.SetPassword (sUserName)
    CreateUser = SUCCESS
    
    Set oUser = Nothing
    Set oContainer = Nothing
    
    Exit Function
ErrorHandler:
    sErrInfo = Err.Number - vbObjectError & ", " & Err.Description & ", " & Err.LastDllError
    Resume Next
End Function

Public Function UserToGroup(sUserName As String, sGroupName As String) As Integer
    On Error GoTo ErrorHandler
    sErrInfo = vbNullString

    If (sNameSpace = vbNullString) Then
        sErrInfo = "NameSpace not set"
        UserToGroup = FAILURE
        Exit Function
    End If
    
    Dim oContainer As IADsContainer
    Dim oGroup As IADsGroup
    Dim oUser As IADsUser
    Dim iRet As Integer
    
    If (sDomain = vbNullString) Then
        Set oContainer = GetObject(sNameSpace & "://" & sComputer)
    Else
        Set oContainer = GetObject(sNameSpace & "://" & sDomain)
    End If
    
    Set oUser = oContainer.GetObject("User", sUserName)
    Set oGroup = oContainer.GetObject("Group", sGroupName)
          
    '// Add the user to the specified group
    Call oGroup.Add(oUser.ADsPath)
    UserToGroup = SUCCESS
    
    Set oUser = Nothing
    Set oGroup = Nothing
    Set oContainer = Nothing
    
    Exit Function
ErrorHandler:
    sErrInfo = Err.Number - vbObjectError & ", " & Err.Description & ", " & Err.LastDllError
    Resume Next
End Function

Public Function ServiceStop(sServiceName As String) As Integer
    On Error GoTo ErrorHandler
    sErrInfo = vbNullString
    
    If (sNameSpace = vbNullString) Then
        sErrInfo = "NameSpace not set"
        ServiceStop = FAILURE
        Exit Function
    End If
    
    Dim oService As IADsService
             
    If (sDomain = vbNullString) Then
        Set oService = GetObject(sNameSpace & "://" & sComputer & "/" & sServiceName)
    Else
        Set oService = GetObject(sNameSpace & "://" & sDomain & "/" & sComputer & "/" & sServiceName)
    End If
    
    oService.Stop
    iRet = oUtility.Pause(STATUS_PAUSE) '// give service time to stop before checking status
    ServiceStop = oService.Status
    Set oService = Nothing
    
    Exit Function
ErrorHandler:
    sErrInfo = Err.Number - vbObjectError & ", " & Err.Description & ", " & Err.LastDllError
    Resume Next
End Function

Public Function ServiceStart(sServiceName As String) As Integer
    On Error GoTo ErrorHandler
    sErrInfo = vbNullString
    
    If (sNameSpace = vbNullString) Then
        sErrInfo = "NameSpace not set"
        ServiceStart = FAILURE
        Exit Function
    End If
    
    Dim oService As IADsService
             
    If (sDomain = vbNullString) Then
        Set oService = GetObject(sNameSpace & "://" & sComputer & "/" & sServiceName)
    Else
        Set oService = GetObject(sNameSpace & "://" & sDomain & "/" & sComputer & "/" & sServiceName)
    End If
    
    oService.Start
    iRet = oUtility.Pause(STATUS_PAUSE) '// give service time to stop before checking status
    ServiceStart = oService.Status
    Set oService = Nothing
    
    Exit Function
ErrorHandler:
    sErrInfo = Err.Number - vbObjectError & ", " & Err.Description & ", " & Err.LastDllError
    Resume Next
End Function

Public Function ServiceStatus(sServiceName As String) As Integer
    On Error GoTo ErrorHandler
    sErrInfo = vbNullString

    If (sNameSpace = vbNullString) Then
        sErrInfo = "NameSpace not set"
        ServiceStatus = FAILURE
        Exit Function
    End If
    
    Dim oService As IADsService
             
    If (sDomain = vbNullString) Then
        Set oService = GetObject(sNameSpace & "://" & sComputer & "/" & sServiceName)
    Else
        Set oService = GetObject(sNameSpace & "://" & sDomain & "/" & sComputer & "/" & sServiceName)
    End If
    
    ServiceStatus = oService.Status
    Set oService = Nothing
    
    Exit Function
ErrorHandler:
    sErrInfo = Err.Number - vbObjectError & ", " & Err.Description & ", " & Err.LastDllError
    Resume Next
End Function

Public Function GetDomain(sComputer As String) As String
    On Error GoTo ErrorHandler
    sErrInfo = vbNullString
    
    If (sNameSpace = vbNullString) Then
        sErrInfo = "NameSpace not set"
        GetDomain = vbNullString
        Exit Function
    End If
    
    Dim oComputer As IADsComputer
    
    Set oComputer = GetObject(sNameSpace & "://" & sComputer)
    GetDomain = Mid(oComputer.Parent, Len(sNameSpace & "://") + 1)
    
    Exit Function
ErrorHandler:
    sErrInfo = Err.Number - vbObjectError & ", " & Err.Description & ", " & Err.LastDllError
    Resume Next
End Function

Public Function CheckIfExists(sComputer As String) As Integer
    On Error GoTo ErrorHandler
    sErrInfo = vbNullString
    
    If (sNameSpace = vbNullString) Then
        sErrInfo = "NameSpace not set"
        CheckIfExists = FAILURE
        Exit Function
    End If
    
    Dim oComputer As IADsComputer
    Set oComputer = GetObject(sNameSpace & "://" & sComputer)
    If (sErrInfo = vbNullString) Then
        CheckIfExists = SUCCESS
    Else
        CheckIfExists = FAILURE
    End If
     
    Exit Function
ErrorHandler:
    sErrInfo = Err.Number - vbObjectError & ", " & Err.Description & ", " & Err.LastDllError
    Resume Next
End Function

Public Function GetOS(sComputer As String) As String
    On Error GoTo ErrorHandler
    sErrInfo = vbNullString
    
    If (sNameSpace = vbNullString) Then
        sErrInfo = "NameSpace not set"
        GetOS = vbNullString
        Exit Function
    End If
    
    Dim oComputer As IADsComputer
    
    If (sDomain = vbNullString) Then
        Set oComputer = GetObject(sNameSpace & "://" & sComputer)
    Else
        Set oComputer = GetObject(sNameSpace & "://" & sDomain & "/" & sComputer)
    End If
    
    GetOS = oComputer.OperatingSystem
    Set oComputer = Nothing
    
    Exit Function
ErrorHandler:
    sErrInfo = Err.Number - vbObjectError & ", " & Err.Description & ", " & Err.LastDllError
    Resume Next
End Function

Public Function GetOSVer(sComputer As String) As String
    On Error GoTo ErrorHandler
    sErrInfo = vbNullString
    
    If (sNameSpace = vbNullString) Then
        sErrInfo = "NameSpace not set"
        GetOSVer = vbNullString
        Exit Function
    End If
    
    Dim oComputer As IADsComputer
    
    If (sDomain = vbNullString) Then
        Set oComputer = GetObject(sNameSpace & "://" & sComputer)
    Else
        Set oComputer = GetObject(sNameSpace & "://" & sDomain & "/" & sComputer)
    End If
    
    GetOSVer = oComputer.OperatingSystemVersion
    Set oComputer = Nothing
    
    Exit Function
ErrorHandler:
    sErrInfo = Err.Number - vbObjectError & ", " & Err.Description & ", " & Err.LastDllError
    Resume Next
End Function

